# stylelens-dataset


## Setup for DB connection
```bash
export DB_DATASET_HOST={your_db_host_url}
export DB_DATASET_PORT={your_db_port_url}
export DB_DATASET_NAME={your_db_name}
export DB_DATASET_USER={your_db_user}
export DB_DATASET_PASSWORD={your_db_password}
```
